@@ -2,6 +2,15 @@ import os
 import inspect
 
 class Environment(object):
+    """
+    A class representing which environment the client library is using.
+    Pass in one of the following values as the first argument to
+    :class:`braintree.Configuration.configure() <braintree.configuration.Configuration>` ::
+
+        braintree.Environment.Sandbox
+        braintree.Environment.Production
+    """
+
     def __init__(self, server, port, is_ssl, ssl_certificate):
         self.__server = server
         self.__port = port
@@ -29,5 +38,5 @@ class Environment(object):
         return os.path.dirname(inspect.getfile(Environment))
 
 Environment.Development = Environment("localhost", os.getenv("GATEWAY_PORT") or "3000", False, None)
-Environment.Sandbox = Environment("sandbox.braintreegateway.com", "443", True, Environment.braintree_root() + "/ssl/valicert_ca.crt")
-Environment.Production = Environment("www.braintreegateway.com", "443", True, Environment.braintree_root() + "/ssl/securetrust_ca.crt")
+Environment.Sandbox = Environment("sandbox.braintreegateway.com", "443", True, Environment.braintree_root() + "/ssl/sandbox_braintreegateway_com.ca.crt")
+Environment.Production = Environment("www.braintreegateway.com", "443", True, Environment.braintree_root() + "/ssl/www_braintreegateway_com.ca.crt")
